* This do-file generates a long daily monthly and yearly dataset of minimum wage legislation.

set more off
capture log close

*** change path to where the publication-materials folder is located on your computer
global path "I:\DataSets5\Duncan\Dropbox\Recent Minimum Wage Changes\Legislation\CHS_Legislation_Lags-revised"


*log using "${path}\data\database_firstdraft.log", replace 

* Load Our Data
	import excel "${path}\data\leg-dates-wide-dataset.xlsx", ///
	sheet("leg-dates-wide-dataset") firstrow case(lower) clear

* Drop uneeded variables
	drop if name ==""
	
* Shorten variable names
	rename statefipscode statefip
	rename stateabbreviation statename
	rename dateoffirstincrease date1
	rename dateofsecondincrease date2
	rename dateofthirdincrease date3
	rename dateoffourthincrease date4
	rename dateoffifthincrease date5
	rename dateofsixthincrease date6
	rename effectiveminimumwageafterfir wage1
	rename effectiveminimumwageaftersec wage2
	rename effectiveminimumwageafterthi wage3
	rename effectiveminimumwageafterfou wage4
	rename effectiveminimumwageafterfif wage5
	rename effectiveminimumwageaftersix wage6
	rename effectiveminimumwage112018 wage2018
	rename minwage wage2011
	rename p wage2012
	rename dateoflastscheduledstatutory end_date
	rename firstlegislationdatepassedby legdate1
	rename firstlegislationdatesignedby govdate1
	rename secondlegislationdatepassedb legdate2
	rename secondlegislationdatesignedb govdate2
	rename thirdlegislationdatepassedby legdate3
	rename thirdlegislationdatesignedby govdate3
	rename fourthlegislationdatepassedb legdate4
	rename fourthlegislationdatesignedb govdate4
	rename fifthdatepassedbylegislature legdate5
	rename fifthdatepassedbygovernor govdate5
	rename ballotinitiative ballot
	rename sizeoffirstincrease first_increase
	rename sizeoftotalincrease total_increase
	rename effectiveminwageafterfinals effective_final
	
	drop bj
	
	
* Generate means and standard deviations of first and last lag and first and total increases for ballot and nonballot increaser states
* We only want to include states with at least 1 statutory increase
	estpost tabstat gov_average_lag_first gov_average_lag_last first_increase total_increase if (first_increase !=.) , by(ballot) ///
	statistics(mean sd) columns(statistics)
	
	estimates store c1
	
	esttab c1 using "${path}/output/summary_stats_ballot.csv", main(mean) aux(sd) nostar unstack ///
	mtitle("Ballot Initiative (0=No 1=Yes)") title("Average Lag Lengths and Increases for Ballot and Legislative States") nonumber replace
	
*** T test of difference in means for ballot and nonballot increaser states
*** We only want to include states with at least 1 statutory increase
	estpost ttest gov_average_lag_first gov_average_lag_last first_increase total_increase if (first_increase !=.) , by(ballot) 
	
	estimates store c1
	
	esttab c1 using "${path}/output/summary_stats_ballot_ttest.csv", wide ///
	mtitle("Ballot Initiative (0=No 1=Yes)") title("Difference in Mean Lag Lengths and Increases for Ballot and Legislative States") nonumber replace
	
*** Label variables
	label var gov_lag_first1 "Gap between governor signature and first increase"
	label var gov_lag_last1 "Gap between governor signature and last increase"
	label var gov_lag_first2 "Gap between governor signature and first increase"
	label var gov_lag_last2 "Gap between governor signature and last increase"
	label var gov_lag_first3 "Gap between governor signature and first increase"
	label var gov_lag_last3 "Gap between governor signature and last increase"
	label var gov_lag_first4 "Gap between governor signature and first increase"
	label var gov_lag_last4 "Gap between governor signature and last increase"
	
* Generate dates for appending series: start from 1/1/2011
	gen year = 2011
	gen month = 1
	gen day = 1
	
	gen dailydate =mdy(month,day,year)
	format dailydate %td 
	drop year month day
	tsset statefip dailydate
	
* Use tsappend to fill down dates to 1/1/2018
	tsappend, last(1jan2018) tsfmt(td)
	
* Fill down relevant data that does not change over time
	foreach var of varlist name-ballot {
		bysort statefip: replace `var' = `var'[1] if missing(`var')
}
* Format date variables as dates not strings
foreach var of varlist date1 date2 date3 date4 date5 date6 end_date legdate1-govdate5 {
	tostring `var', replace format(%20.0f)
	replace `var' = "0" + `var' if length(`var') == 7
	destring `var', replace
	format `var' %td
}

	gen effectiveminwage =.

	di date("01012013","MDY")
	
* Fill in long effective minimum wage variable
* 
	replace effectiveminwage = pre2013minwage if dailydate < date1
	replace effectiveminwage = wage1 if date1 <= dailydate & dailydate < date2
	replace effectiveminwage = wage2 if date2 <= dailydate & dailydate < date3
	replace effectiveminwage = wage3 if date3 <= dailydate & dailydate < date4
	replace effectiveminwage = wage4 if date4 <= dailydate & dailydate < date5
	replace effectiveminwage = wage5 if date5 <= dailydate & dailydate < date6
	replace effectiveminwage = wage6 if date6 <= dailydate
	
	rename dailydate date
	
* Generate long legislation and signature date variables

* The legislation_date is:
 
* 1) For increases through legislation the date when a bill increasing the minimum wage is passsed by the state legislature
* 2) For increases approved by ballot, the date when the vote took place

* The legislation_date is:
 
* 1) For increases through legislation the date when a bill increasing the minimum wage is passsed by the state legislature
* 2) For increases approved by ballot, the date when the vote took place

	gen legislation_date =.
	gen signature_date =.

* Fill in legislation date and signature date long variables
	replace legislation_date = legdate1 if legdate1 !=. & date >= date1 & date < date2
	replace signature_date = govdate1 if govdate1 !=. & date >= date1 & date < date2
	
* If only 1 piece of legislation, fill in approval date for first bill as legislation and signature dates 
	replace legislation_date = legdate1 if legdate2 ==. 
	replace signature_date = govdate1 if govdate2 ==. 
	
* If 2 pieces of legislation, fill in date for second bill if the date is after the second increase takes effect 
	replace legislation_date = legdate2 if legdate2 !=. & date >= date2 & date < date3
	replace signature_date = govdate2 if govdate2 !=. & date >= date2 & date < date3
	
* If 3 pieces of legislation, fill in date for third bill if the date is after the third increase takes effect 
	replace legislation_date = legdate3 if legdate3 !=. & date >= date3 & date < date4
	replace signature_date = govdate3 if govdate3 !=. & date >= date3 & date < date4
	
* If 4 pieces of legislation, fill in date for fourth bill if the date is after the fourth increase takes effect 
	replace legislation_date = legdate4 if legdate4 !=. & date >= date4 & date < date5
	replace signature_date = govdate4 if govdate4 !=. & date >= date4 & date < date5
	
* If 5 pieces of legislation, fill in date for fifth bill if the date is after the fifth increase takes effect 
	replace legislation_date = legdate5 if legdate5 !=. & date >= date5
	replace signature_date = govdate5 if govdate5 !=. & date >= date5
	
	by statefip: replace legislation_date = legislation_date[_n-1] if legislation_date ==.
	by statefip: replace signature_date = signature_date[_n-1] if signature_date==.
	

	format legislation_date %td
	format signature_date %td
	
	
* Fill in first and total increases by state
* If state had no increases by statute or ballot, leave blank
	by statefip: replace first_increase = first_increase[1]
	by statefip: replace total_increase = total_increase[1]
	by statefip: replace first_increase =. if date < date1
	by statefip: replace total_increase =. if date < date1
	
	drop legdate1-govdate4 date1-wage6 
	
* Fix Florida in 2011 - Increase from 7.25-7.31 effective 6/1/2011
	di date("05312011","MDY")
	replace wage2011 = 7.25 if statefip==12 & date <=18778
	
	
* Recast float to double before rounding
	recast double effectiveminwage
	
	foreach var of varlist effectiveminwage first_increase total_increase {
		replace `var' = round(`var', .01)
	}
	
	gen day = day(date)
	gen month = month(date)
	gen year = year(date)
	
	order statefip name statename date effectiveminwage ballot legislation_date signature_date first_increase total_increase, first
		
*** Fill in minimum wage for indexer states for 2011 and 2012
	replace effectiveminwage = wage2011 if year==2011
	replace effectiveminwage = wage2012 if year==2012
	
* Generate indexer to increaser and increaser to indexer indicators
* Indicate the year the transition occurs
	drop indexertoincreaser increasertoindexer
	gen increasertoindexer =0
	
	replace increasertoindexer = 1 if statefip == 34 & year == 2014
	replace increasertoindexer =1 if statefip == 46 & year == 2015
	
	gen indexertoincreaser =0
	replace indexertoincreaser = 1 if statefip == 4 & year == 2016
	replace indexertoincreaser = 1 if statefip == 8 & year == 2016  
	replace indexertoincreaser = 1 if statefip == 23 & year == 2016
	replace indexertoincreaser = 1 if statefip == 41 & year == 2016
	replace indexertoincreaser = 1 if statefip == 53 & year == 2016
	replace indexertoincreaser = 1 if statefip == 50 & year == 2014

* Round the effective minimum wage variable to the nearest cent
	replace effectiveminwage = round(effectiveminwage, .01)
	
* Label created variables
	label var originaltype "Indexer or increaser status on 1/1/2011"
	label var effectiveminwage "Maximum of state and federal minimum wage"
	label var legislation_date "Date increase passed by state legislature"
	label var signature_date "Date increase signed by state governor"
	label var leg_average_lag_first "Average number of days between legislation_date and date first increase takes effect"
	label var leg_average_lag_last "Average number of days between legislation_date and date last increase takes effect"
	label var gov_average_lag_first "Average number of days between signature_date and date first increase takes effect"
	label var gov_average_lag_last "Average number of days between signature_date and date last increase takes effect"
	label var day "Day"
	label var month "Month"
	label var year "Year"
	label var increasertoindexer "Transition from increaser to indexer (1=yes)"
	label var indexertoincreaser "Transition from indexer to increaser (1=yes)"
	
	drop pre2013minwage

	foreach var of varlist increasertoindexer-indexer {
		replace `var' =0 if `var'==.
	}
	
*** Uncomment this line if you want a .dta file that is readable directly in Stata
	save "${path}\data\legislation_daily.dta", replace
	
	outsheet using "${path}\data\legislation_daily.csv", comma replace
	
*** Generate Monthly Database for merging with a monthly dataset like the CPS: keep only the first day of each month
	keep if day ==1

*** Uncomment this line if you want a .dta file that is readable directly in Stata
	save "${path}\data\legislation_monthly.dta", replace
	
	outsheet using "${path}\data\legislation_monthly.csv", comma replace
	
*** Generate Yearly Database for merging with a yearly dataset like the ACS: keep only the minimum wage on January 1 of a given year
	keep if month ==1

*** Uncomment this line if you want a .dta file that is readable directly in Stata
	save "${path}\data\legislation_yearly.dta", replace
	
	outsheet using "${path}\data\legislation_yearly.csv", comma replace
	
log close
